@@ -12,9 +12,9 @@ from typing import Dict
 from typing import Iterator
 from typing import List
 from typing import Optional
-from typing import overload
 from typing import Sequence
 from typing import Set
+from typing import overload
 from unittest import mock
 
 from sqlalchemy.orm.exc import MultipleResultsFound
@@ -24,6 +24,7 @@ from .comparison import ExpressionMatcher
 from .utils import build_identity_map
 from .utils import copy_and_update
 from .utils import get_item_attr
+from .utils import get_scalar
 from .utils import indexof
 from .utils import raiser
 from .utils import setattr_tmp
@@ -170,7 +171,6 @@ class AlchemyMagicMock(mock.MagicMock):
         _new_parent: Optional[Any] = ...,
         **kwargs: Any,
     ) -> None:
-        """Creates AlchemyMagicMock that can be used as limited SQLAlchemy session."""
         ...  # pragma: no cover
 
     def __init__(self, *args, **kwargs) -> None:
@@ -312,17 +312,11 @@ class UnifiedAlchemyMagicMock(AlchemyMagicMock):
         1
         >>> s.query('bar').filter(c == 'one').filter(c == 'two').first()
 
-        # .one()
+        # .one() and scalar
         >>> s.query('foo').filter(c == 'three').one()
         3
-        >>> s.query('bar').filter(c == 'one').filter(c == 'two').one()
-        Traceback (most recent call last):
-        ...
-        sqlalchemy.orm.exc.NoResultFound: No row was found for one()
-        >>> s.query('foo').filter(c == 'one').filter(c == 'two').one()
-        Traceback (most recent call last):
-        ...
-        sqlalchemy.orm.exc.MultipleResultsFound: Multiple rows were found for one()
+        >>> s.query('foo').filter(c == 'three').scalar()
+        3
         >>> s.query('bar').filter(c == 'one').filter(c == 'two').one_or_none()
 
         # .get()
@@ -423,6 +417,8 @@ class UnifiedAlchemyMagicMock(AlchemyMagicMock):
         1
         >>> s.query(SomeClass).delete()
         0
+        >>> s.query(SomeClass).scalar()
+        None
 
     Also note that only within same query functions are unified.
     After ``.all()`` is called or query is iterated over, future queries
@@ -452,6 +448,7 @@ class UnifiedAlchemyMagicMock(AlchemyMagicMock):
             else None
         ),
         "get": lambda x, idmap: get_item_attr(build_identity_map(x), idmap),
+        "scalar": lambda x: get_scalar(x),
     }
     unify: Dict[str, Optional[UnorderedCall]] = {
         "query": None,
@@ -483,7 +480,6 @@ class UnifiedAlchemyMagicMock(AlchemyMagicMock):
         _new_parent: Optional[Any] = ...,
         **kwargs: Any,
     ) -> None:
-        """Creates an UnifiedAlchemyMagicMock to mock a SQLAlchemy session."""
         ...  # pragma: no cover
 
     def __init__(self, *args, **kwargs) -> None:
@@ -544,7 +540,6 @@ class UnifiedAlchemyMagicMock(AlchemyMagicMock):
         two: bool = ...,
         from_kall: bool = ...,
     ) -> None:
-        """Unify the SQLAlchemy expressions."""
         ...  # pragma: no cover
 
     def _unify(self, *args, **kwargs) -> Any:
